@@ -2,7 +2,7 @@
 # -*- coding:utf-8 -*-
 # This Python file uses the following encoding: utf-8
 
-VERSION = (0,4,9)
+VERSION = (0,5,0)
 APPLICATION_NAME = "Dynamic Link"
 VERSION_str = str(VERSION).strip('()').replace(',','.').replace(' ','')
 VERSION_INFO = """
@@ -12,6 +12,11 @@ Modification date: 03.08.2011
 Hints:
 
 
+- 0.5.0     some changes - stable release
+- 0.4.9.4   install_requires in setup.py modified
+- 0.4.9.3   old data removed
+- 0.4.9.2   dl_settings removed
+- 0.4.9.1   Readme updatet
 - 0.4.9     Testet with Django 1.2 u. 1.3
 - 0.4.8.4   Some small changes
 - 0.4.8.3   Some small changes
